document.addEventListener('DOMContentLoaded', () => {
  // Mobile menu toggle
  const menuToggle = document.querySelector('.menu-toggle');
  const navLinks = document.querySelector('.nav-links');
  
  menuToggle?.addEventListener('click', () => {
    navLinks.classList.toggle('active');
  });

  // Weight tracking functionality
  const weightForm = document.getElementById('weight-form');
  const weightChart = document.getElementById('weight-chart');
  
  let weightData = JSON.parse(localStorage.getItem('weightData')) || [];

  function updateChart() {
    const ctx = weightChart.getContext('2d');
    ctx.clearRect(0, 0, weightChart.width, weightChart.height);
    
    if (weightData.length > 0) {
      // Simple line chart implementation
      ctx.beginPath();
      ctx.moveTo(0, weightChart.height - (weightData[0].weight * 2));
      
      weightData.forEach((data, index) => {
        const x = (index / (weightData.length - 1)) * weightChart.width;
        const y = weightChart.height - (data.weight * 2);
        ctx.lineTo(x, y);
      });
      
      ctx.strokeStyle = '#3498db';
      ctx.lineWidth = 2;
      ctx.stroke();
    }
  }

  function updateRecommendations() {
    const recommendations = document.getElementById('diet-recommendations');
    const latestWeight = weightData[weightData.length - 1]?.weight;
    const goalWeight = document.getElementById('goal').value;

    if (latestWeight && goalWeight) {
      const diff = latestWeight - goalWeight;
      let recommendationText = '';

      if (diff > 0) {
        recommendationText = `
          <div class="recommendation-card">
            <h3>Weight Loss Recommendations</h3>
            <ul>
              <li>Aim for a caloric deficit of 500 calories per day</li>
              <li>Increase protein intake to preserve muscle mass</li>
              <li>Include more vegetables in your meals</li>
              <li>Stay hydrated with at least 8 glasses of water daily</li>
            </ul>
          </div>
        `;
      } else if (diff < 0) {
        recommendationText = `
          <div class="recommendation-card">
            <h3>Weight Gain Recommendations</h3>
            <ul>
              <li>Increase caloric intake by 500 calories per day</li>
              <li>Focus on nutrient-dense foods</li>
              <li>Include healthy fats in your diet</li>
              <li>Consume protein-rich foods with each meal</li>
            </ul>
          </div>
        `;
      } else {
        recommendationText = `
          <div class="recommendation-card">
            <h3>Maintenance Recommendations</h3>
            <ul>
              <li>Maintain current caloric intake</li>
              <li>Focus on balanced nutrition</li>
              <li>Stay active and consistent with exercise</li>
              <li>Monitor weight weekly</li>
            </ul>
          </div>
        `;
      }
      
      recommendations.innerHTML = recommendationText;
    }
  }

  weightForm?.addEventListener('submit', (e) => {
    e.preventDefault();
    const weight = parseFloat(document.getElementById('weight').value);
    const date = new Date().toISOString();
    
    weightData.push({ weight, date });
    localStorage.setItem('weightData', JSON.stringify(weightData));
    
    updateChart();
    updateRecommendations();
  });

  // Initialize chart and recommendations
  updateChart();
  updateRecommendations();
});
